Benchmarking Code
==================

In ProbNum computational cost with regard to time and memory is measured via a benchmark suite.
Benchmarks are run by `airspeed velocity <https://asv.readthedocs.io/en/stable/>`_ which tracks
performance changes over time.


Check out ProbNum's benchmarks for its probabilistic numerical methods
and related functions:

.. toctree::
   :maxdepth: 1

   ProbNum's Benchmarks <https://probabilistic-numerics.github.io/probnum-benchmarks/benchmarks/>



Creating Benchmarks
********************
You can add a new benchmark by following `this tutorial <https://asv.readthedocs.io/en/stable/writing_benchmarks.html>`_.
